.. oHySEM documentation master file, created by Erik Alvarez

Research projects
=================

The model has being used in this research project:

- Flexible electric demand management in markets with high penetration of renewable sources (DEFINER), developed for the **Ministry of Science and Innovation/State Research Agency** (10.13039/501100011033) under the program **Public-Private Partnerships** with **NextGenerationEU/PRTR** funds (CPP2021-008786). December 2022 - November 2025.
  `A. Ramos <https://www.iit.comillas.edu/people/aramos>`_, `J.M. Latorre <https://www.iit.comillas.edu/people/jesuslc>`_, `P. Sanchez <https://www.iit.comillas.edu/people/psanchez>`_, `E.F. Álvarez <https://www.iit.comillas.edu/people/ealvarezq>`_, `P. Rodilla <https://www.iit.comillas.edu/people/prodilla>`_, `P. Mastropietro <https://www.iit.comillas.edu/people/pmastropietro>`_, `C. Batlle <https://www.iit.comillas.edu/people/batlle>`_, `A. Bello <https://www.iit.comillas.edu/people/abello>`_, `D.M. Navarrete <https://www.iit.comillas.edu/people/dmnavarrete>`_

.. image:: /../img/ColabPP.png
   :scale: 30%
   :align: center
